*-------------------------------------------------------------------------------------*
* Configuration                                                                       *
* ------------------------------------------------------------------------------------*

*-------------------------------- specify your paths here! ---------------------------*


global dataDir 	"_SET_PATH_HERE_" // original data

global dir 		"_SET_PATH_HERE_" // folder with the project

global data		"${dir}/data"	
global posted	"${dir}/posted"
global graphs 	"${dir}/graphs"
global tables	"${dir}/tables"


use "${posted}/data", clear

*-----------------------------------------------------------------------------*
* Figure 1       										                      *
*-----------------------------------------------------------------------------*
graph bar 	edu_low edu_mid edu_high if n == 1, 						    ///
			percent over(cohort, gap(10)) over (male, gap(40))			    ///
			bar(1, bcolor(gs14)) bar(2, bcolor(gs12)) bar(3, bcolor(gs10))  ///
			bar(4, bcolor(gs14)) bar(5, bcolor(gs12)) bar(6, bcolor(gs10))  ///
			graphregion(color(white) fcolor(white) icolor(white)) 		    ///
			stack title("Education by Cohort", size(medium)) 			    ///
			legend(title(Level of Education, size(medium)) 				    ///
			label(1 "Low") label(2 "Intermediate") label(3 "High") 		    ///
			size(medium) rows(1)) yline(20 40 60 80 ,lwidth(0.25 ) 		    ///
			lcolor(black)) ytitle("") ylabel(, labsize(small) angle(0))     ///
			saving("$graphs/figure_1.gph", replace)

			
*-----------------------------------------------------------------------------*
* Table 2        										                      *
*-----------------------------------------------------------------------------*

* Generate variable for description of panel attrition

/*
 Deaths are set to missing in order to calculate the proportion of those who 
have left the panel due to other reasons. This is done only for descriptives.
*/

gen left_descr = left
replace left_descr = . if died==1

* Statistics for time-varying variables calculated for observations (not for cases)

eststo clear
eststo descr_t:  estpost sum srh age age_c  // total sample
eststo descr_c1: estpost sum srh age        if cohort==1930 // cohort 1
esttab descr_t descr_c1 										 	///
	using "$tables/table_2.rtf", replace label 					 	///
	cells("mean(fmt(a2)) sd(fmt(a2)) min(fmt(a2)) max(fmt(a2))") 	///
	mtitles("Total" "1930-39")
  
eststo descr_c2: estpost sum srh age        if cohort==1940 // cohort 2
eststo descr_c3: estpost sum srh age        if cohort==1950 // cohort 3
eststo descr_c4: estpost sum srh age        if cohort==1960 // cohort 4

esttab descr_c2 descr_c3 descr_c4											///
	using "$tables/table_2.rtf", append label 						///
	cells("mean(fmt(a2)) sd(fmt(a2)) min(fmt(a2)) max(fmt(a2))") 	///
	mtitles("1940-49" "1950-59" "1960-69")

	
* Statistics for time constant variables calculated for cases (not for observations)

eststo clear
eststo descr_t:  estpost sum gebjahr coh coh_c edu_low edu_mid edu_high ///
							 male died left_descr N if n == 1   // total sample
eststo descr_c1: estpost sum gebjahr edu_low edu_mid edu_high ///
							 male died left_descr N if cohort==1930 & n == 1 //  cohort 1
esttab descr_t descr_c1 											///
	using "$tables/table_2.rtf", append label 						///
	cells("mean(fmt(a2)) sd(fmt(a2)) min(fmt(a2)) max(fmt(a2))") 	///
	mtitles("Total" "1930-39")

eststo descr_c2: estpost sum gebjahr edu_low edu_mid edu_high ///
							 male died left_descr N if cohort==1940 & n == 1 // cohort 2
eststo descr_c3: estpost sum gebjahr edu_low edu_mid edu_high ///
							 male died left_descr N if cohort==1950 & n == 1 // cohort 3
eststo descr_c4: estpost sum gebjahr edu_low edu_mid edu_high ///
							 male died left_descr N if cohort==1960 & n == 1 // cohort 3							 
							 
esttab descr_c2 descr_c3 descr_c4 											///
	using "$tables/table_2.rtf", append label 						///
	cells("mean(fmt(a2)) sd(fmt(a2)) min(fmt(a2)) max(fmt(a2))") 	///
	mtitles("1940-49" "1950-59" "1960-69")

	
*************************************************
*               Table attrition                 *
*************************************************

gen srh_w1 = srh if syear ==1992

bysort edu_cat: sum died left stayed if n==1
bysort edu_cat: sum gebjahr male N srh_w1 if n==1 & died   ==1
bysort edu_cat: sum gebjahr male N srh_w1 if n==1 & left   ==1	
bysort edu_cat: sum gebjahr male N srh_w1 if n==1 & stayed ==1	


*************************************************
*              MULTIVARIATE ANALYSIS            *
*************************************************

* TABLE 3 
eststo clear

eststo: xtmixed srh c.age_c##c.coh_c##i.edu_cat    ///
                    c.age_2_c c.age_3_c c.age_4_c  ///
					i.died i.left  	               ///			
					i.male						   ///
				    || pid: age_c, var cov(unstr) 
					
eststo: xtmixed srh c.age_c##c.coh_c##i.edu_cat    ///
                    c.age_2_c c.age_3_c c.age_4_c  ///
					i.died i.left  	               ///			
					if male == 1		      		/// 
				    || pid: age_c, var cov(unstr) 					
									
eststo: xtmixed srh c.age_c##c.coh_c##i.edu_cat    ///
                    c.age_2_c c.age_3_c c.age_4_c  ///
					i.died i.left  	               ///			
					if male == 0		            /// 
				    || pid: age_c, var cov(unstr)					
					
					
esttab using "$tables\table_3.rtf", replace label se wide  ///
starlevels(* 0.05 ** 0.01) b(a2) mtitles("All" "Men" "Women")		


* Figure 2
	
** All					
					
xtmixed srh c.age_c##c.coh_c##i.edu_cat    ///
            c.age_2_c c.age_3_c c.age_4_c  ///
		    i.died i.left  	               ///			
			i.male						   ///
		    || pid: age_c, var cov(unstr) 
					
rename died  died_0
gen died =0          // fixing the dead variable at the value 0
rename left  left_0
gen left =0          // fixing the dropout variable at the value 0
rename male  male_0
gen male =0          // fixing the male variable at 0
rename coh_c  coh_0
gen coh_c  = 0
capture drop all
predict all   // generating a variable that includes predicted values from the model above, given the fixed values above
drop died left male coh_c // dropping renamed variables to retain the initial ones
rename died_0  died
rename left_0  left
rename coh_0   coh_c
rename male_0   male
			
graph twoway 	line all age if edu_cat==3, 	lcolor(gs12)  lwidth(medthick) sort  ///
			||	line all age if edu_cat==1, 	lcolor(black) lwidth(medthick) sort	///
	graphregion(color(white) fcolor(white) icolor(white)) ylabel(2.5(.2)4.3, labsize(small) angle(0)) 		///
	title("Men and Women", size(small) col(black))																	///
	xlabel(30(10)80, labsize(small)) xtitle("Age", size(small)) ytitle("Self-Rated Health", size(small))	///
	plotregion(color(white) fcolor(white) icolor(white)) legend(off) ///
	name(all_ca, replace) 	

	
** Men					
					
xtmixed srh c.age_c##c.coh_c##i.edu_cat    ///
            c.age_2_c c.age_3_c c.age_4_c  ///
		    i.died i.left  	               ///			
			if male						   ///
		    || pid: age_c, var cov(unstr) 
					
rename died  died_0
gen died =0          // fixing the dead variable at the value 0
rename left  left_0
gen left =0          // fixing the dropout variable at the value 0
rename coh_c  coh_0
gen coh_c  = 0
capture drop men
predict men   // generating a variable that includes predicted values from the model above, given the fixed values above
drop died left coh_c // dropping renamed variables to retain the initial ones
rename died_0  died
rename left_0  left
rename coh_0   coh_c
			
graph twoway 	line men age if edu_cat==3, 	lcolor(gs12)  lwidth(medthick) sort  ///
			||	line men age if edu_cat==1, 	lcolor(black) lwidth(medthick) sort	///
	graphregion(color(white) fcolor(white) icolor(white)) ylabel(2.5(.2)4.3, labsize(small) angle(0)) 		///
	title("Men", size(small) col(black))																	///
	xlabel(30(10)80, labsize(small)) xtitle("Age", size(small)) ytitle("Self-Rated Health", size(small))	///
	plotregion(color(white) fcolor(white) icolor(white)) legend(off) ///
	name(men_ca, replace)   	


** Women					
					
					
xtmixed srh c.age_c##c.coh_c##i.edu_cat    ///
            c.age_2_c c.age_3_c c.age_4_c  ///
		    i.died i.left  	               ///			
			if !male					   ///
		    || pid: age_c, var cov(unstr) 
						
					
rename died  died_0
gen died =0          // fixing the dead variable at the value 0
rename left  left_0
gen left =0          // fixing the dropout variable at the value 0
rename coh_c  coh_0
gen coh_c  = 0
capture drop women
predict women   // generating a variable that includes predicted values from the model above, given the fixed values above
drop died left coh_c // dropping renamed variables to retain the initial ones
rename died_0  died
rename left_0  left
rename coh_0   coh_c
			
graph twoway 	line women age if edu_cat==3, 	lcolor(gs12)  lwidth(medthick) sort  ///
			||	line women age if edu_cat==1, 	lcolor(black) lwidth(medthick) sort	///
	graphregion(color(white) fcolor(white) icolor(white)) ylabel(2.5(.2)4.3, labsize(small) angle(0)) 		///
	title("Women", size(small) col(black))																	///
	xlabel(30(10)80, labsize(small)) xtitle("Age", size(small)) ytitle("Self-Rated Health", size(small))	///
	plotregion(color(white) fcolor(white) icolor(white)) legend(off) ///
	name(women_ca, replace)   		
	


graph combine all_ca men_ca women_ca, ///
              graphregion(fcolor(white)) row (1) xcommon ycommon xsize(15) ysize(5) iscale(1) 
			  
graph save $graphs/figure3.gph, replace


* Table A1

eststo clear

xtmixed srh c.age_c##i.cohort##i.edu_cat      ///
		    c.age_2_c c.age_3_c c.age_4_c     ///
		    i.died i.left  	                  ///			
		    if male					          ///
		    || pid: , var cov(unstr) 

					
esttab using "$tables\table_A1_jhsb.rtf", replace label se wide b(a2) ///
starlevels(* 0.05 ** 0.01) mtitles("Model 4")		


*Figure 4

rename died  died_0
gen died =0          // fixing the dead variable at the value 0
rename left  left_0
gen left =0          // fixing the dropout variable at the value 0

cap drop menc
predict menc   // generating a variable that includes predicted values from the model above, given the fixed values above

drop died left       // dropping renamed variables to retain the initial ones
rename died_0  died
rename left_0  left

sort age

graph twoway 	line menc age if cohort==1930 & edu_cat==1, lcolor(black) lwidth(medthick)   ///
			||  line menc age if cohort==1940 & edu_cat==1, lcolor(black) lwidth(medthick)	///
			||  line menc age if cohort==1950 & edu_cat==1, lcolor(black) lwidth(medthick)	///
			||  line menc age if cohort==1960 & edu_cat==1, lcolor(black) lwidth(medthick)	///
			||  line menc age if cohort==1930 & edu_cat==3, lcolor(gs12)  lwidth(medthick)	///
			||	line menc age if cohort==1940 & edu_cat==3, lcolor(gs12)  lwidth(medthick)   	///
			||  line menc age if cohort==1950 & edu_cat==3, lcolor(gs12)  lwidth(medthick)	///
			||  line menc age if cohort==1960 & edu_cat==3, lcolor(gs12)  lwidth(medthick)	///
    graphregion(color(white) fcolor(white) icolor(white)) ylabel(2.3(.2)4.1, angle(0) labsize(small))   ///	
	xline(33 43 54 64 74, lpattern(dash) lwidth(thin) lcolor(gs10))                                     ///
	xlabel(25(5)85, labsize(small)) xtitle("Age", size(small)) ytitle("Self-Rated Health", size(small))	///
	plotregion(color(white) fcolor(white) icolor(white)) legend(off)                                    ///
	name(fig4_men, replace)
	
graph save $graphs/figure_4.gph, replace
	
	
* Table 4

eststo clear
eststo e0:  xtmixed srh c.age##i.cohort##i.edu_cat      ///
		    c.age##c.age##c.age##c.age      ///
		    i.died i.left  	                ///			
		    if male					        ///
		    || pid: , var cov(unstr) 

eststo e_1: margins, dydx(edu) at(c.age = (33 43 54)    cohort = (1960))

eststo e_2: margins, dydx(edu) at(c.age = (33 43 54 64) cohort = (1950))

eststo e_3: margins, dydx(edu) at(c.age = (43 54 64 74) cohort = (1940))

eststo e_4: margins, dydx(edu) at(c.age = (54 64 74)    cohort = (1930))
